==> qt-creator-opensource-src-4.15.0.zip: qt-creator-opensource-src-4.15.0/src/plugins/autotest/catch/catchframework.cpp <==
/****************************************************************************
**
** Copyright (C) 2019 Jochen Seemann
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "catchframework.h"

#include "catchtestparser.h"
#include "catchtreeitem.h"

namespace Autotest {
namespace Internal {

const char *CatchFramework::name() const
{
    return "Catch";
}

unsigned CatchFramework::priority() const
{
    return 12;
}

ITestParser *CatchFramework::createTestParser()
{
    return new CatchTestParser(this);
}

ITestTreeItem *CatchFramework::createRootNode()
{
    return new CatchTreeItem(this,
                             QCoreApplication::translate("CatchFramework", "Catch Test"),
                             QString(), ITestTreeItem::Root);
}

} // namespace Internal
} // namespace Autotest

==> qt-creator-opensource-src-6.0.1.zip: qt-creator-opensource-src-6.0.1/src/plugins/autotest/catch/catchframework.cpp <==
/****************************************************************************
**
** Copyright (C) 2019 Jochen Seemann
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "catchframework.h"

#include "catchtestparser.h"
#include "catchtreeitem.h"

namespace Autotest {
namespace Internal {

const char *CatchFramework::name() const
{
    return "Catch";
}

unsigned CatchFramework::priority() const
{
    return 12;
}

ITestParser *CatchFramework::createTestParser()
{
    return new CatchTestParser(this);
}

ITestTreeItem *CatchFramework::createRootNode()
{
    return new CatchTreeItem(this,
                             QCoreApplication::translate("CatchFramework", "Catch Test"),
                             Utils::FilePath(), ITestTreeItem::Root);
}

} // namespace Internal
} // namespace Autotest
